@@ -6,6 +6,7 @@ import (
 	"bytes"
 	"container/list"
 	"fmt"
+	"math"
 	"strconv"
 	"strings"
 
@@ -320,7 +321,7 @@ func deepCloneWithOptions(node *yaml.Node, cloneContent bool) *yaml.Node {
 }
 
 // yaml numbers can be hex encoded...
-func parseInt(numberString string) (string, int64, error) {
+func parseInt64(numberString string) (string, int64, error) {
 	if strings.HasPrefix(numberString, "0x") ||
 		strings.HasPrefix(numberString, "0X") {
 		num, err := strconv.ParseInt(numberString[2:], 16, 64)
@@ -330,6 +331,25 @@ func parseInt(numberString string) (string, int64, error) {
 	return "%v", num, err
 }
 
+func parseInt(numberString string) (int, error) {
+	var err error
+	var parsed int64
+	if strings.HasPrefix(numberString, "0x") ||
+		strings.HasPrefix(numberString, "0X") {
+		parsed, err = strconv.ParseInt(numberString[2:], 16, 64)
+	} else {
+		parsed, err = strconv.ParseInt(numberString, 10, 64)
+	}
+
+	if err != nil {
+		return 0, err
+	} else if parsed > math.MaxInt {
+		return 0, fmt.Errorf("%v is too big (larger than %v)", parsed, math.MaxInt)
+	}
+
+	return int(parsed), err
+}
+
 func createScalarNode(value interface{}, stringValue string) *yaml.Node {
 	var node = &yaml.Node{Kind: yaml.ScalarNode}
 	node.Value = stringValue
